from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Diag(object):
    """
    Troubleshooting Tools - Diagnostics API
    
    Implements GET POST DEL PUT methods for Diagnostics endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getDBSchema(self):
        """
        Get the current database schema
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/diagnostics/dbschema"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getThreadPools(self):
        """
        Get information on the threadpools
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/diagnostics/threadpools"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPostAggregationAppDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/speedtest/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSessionInfoCapture(self, payload):
        """
        getSessionInfoCapture Description
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def disablePacketCaptureSession(self, sessionId):
        """
        disablePacketCaptureSession Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/disable/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadFile(self, sessionId):
        """
        downloadFile Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/download/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def forceStopPcapSession(self, sessionId):
        """
        forceStopPcapSession Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/forcedisbale/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def startPcapSession(self, sessionId):
        """
        startPcapSession Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/start/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFileDownloadStatus(self, sessionId):
        """
        getFileDownloadStatus Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/status/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def stopPcapSession(self, sessionId):
        """
        stopPcapSession Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/stop/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def formPostPacketCapture(self, deviceUUID, sessionId):
        """
        formPostPacketCapture Description
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/capture/{deviceUUID}/{sessionId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getSessionInfoLog(self, payload):
        """
        getSessionInfoLog Description
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def disableDeviceLog(self, sessionId):
        """
        disableDeviceLog Description
        
        Parameters:
        sessionId	 (string):	Session Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/disable/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadDebugLog(self, sessionId):
        """
        downloadDebugLog Description
        
        Parameters:
        sessionId	 (string):	Session Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/download/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def renewSessionInfo(self, sessionId):
        """
        renewSessionInfo Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/renew/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def searchDeviceLog(self, payload, sessionId):
        """
        searchDeviceLog Description
        
        Parameters:
        payload:    Request Payload
		sessionId	 (string):	Session Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/search/{sessionId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getSessions(self):
        """
        getSessions Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/sessions"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def clearSession(self, sessionId):
        """
        clearSession Description
        
        Parameters:
        sessionId	 (string):	Session Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/sessions/clear/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLogType(self, uuid):
        """
        getLogType Description
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/type?uuid={uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def streamLog(self, payload, logType, deviceUUID, sessionId):
        """
        streamLog Description
        
        Parameters:
        payload:    Request Payload
		logType	 (string):	Log type
		deviceUUID	 (string):	Device uuid
		sessionId	 (string):	Session Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/{logType}/{deviceUUID}/{sessionId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getDeviceLog(self, sessionId, logId):
        """
        getDeviceLog Description
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/log/{sessionId}?logId={logId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPostAggregationAppDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getConcurrentData(self, traceId, timestamp):
        """
        getConcurrentData Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/concurrentData?traceId={traceId}&timestamp={timestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConcurrentDomainData(self, traceId, timestamp):
        """
        getConcurrentDomainData Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/concurrentDomainData?traceId={traceId}&timestamp={timestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getDomainMetric(self, traceId, timestamp, domain, firstTimestamp, lastTimestamp):
        """
        getDomainMetric Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		domain	 (string):	domain name
		firstTimestamp	 (integer):	first timestamp of xAxis
		lastTimestamp	 (integer):	last timestamp of xAxis
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/domainMetric?traceId={traceId}&timestamp={timestamp}&domain={domain}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFinalizedData(self, traceId, timestamp):
        """
        getFinalizedData Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/finalizedData?traceId={traceId}&timestamp={timestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFinalizedDomainData(self, traceId, timestamp):
        """
        getFinalizedDomainData Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/finalizedDomainData?traceId={traceId}&timestamp={timestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFlowDetail(self, traceId, timestamp, flowId):
        """
        getFlowDetail Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		flowId	 (integer):	flow id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/flowDetail?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFlowMetric(self, traceId, timestamp, flowId, firstTimestamp, lastTimestamp):
        """
        getFlowMetric Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		flowId	 (integer):	flow id
		firstTimestamp	 (integer):	first timestamp of xAxis
		lastTimestamp	 (integer):	last timestamp of xAxis
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/flowMetric?traceId={traceId}&timestamp={timestamp}&flowId={flowId}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMonitorState(self, traceId, state):
        """
        getMonitorState Description
        
        Parameters:
        traceId	 (integer):	trace id
		state	 (string):	trace state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/getMonitorState?traceId={traceId}&state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def monitorStart(self, payload):
        """
        CXP Monitor Action - Start
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/monitor/start"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def monitorStop(self, payload):
        """
        CXP Monitor Action - Stop
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/monitor/stop"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getNwpiDscp(self):
        """
        getNwpiDscp Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/nwpiDSCP"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNwpiNbarAppGroup(self):
        """
        getNwpiNbarAppGroup Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/nwpiNbarAppGroup"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNwpiProtocol(self):
        """
        getNwpiProtocol Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/nwpiProtocol"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPacketFeatures(self, traceId, timestamp, flowId):
        """
        getPacketFeatures Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		flowId	 (integer):	flow id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/packetFeatures?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def traceDelete(self, traceId, timestamp):
        """
        Trace Action - Delete
        
        Parameters:
        traceId	 (string):	trace id
		timestamp	 (integer):	start time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/trace/delete?traceId={traceId}&timestamp={timestamp}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def traceStart(self, payload):
        """
        Trace Action - Start
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/trace/start"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def traceStop(self, traceId):
        """
        Trace Action - Stop
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/trace/stop/{traceId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def traceFinFlowWithQuery(self, traceId, timestamp, query):
        """
        Retrieve Certain Fin Flows
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/traceFinFlowWithQuery?traceId={traceId}&timestamp={timestamp}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTraceFlow(self, traceId, timestamp, state):
        """
        getTraceFlow Description
        
        Parameters:
        traceId	 (integer):	trace id
		timestamp	 (integer):	start time
		state	 (string):	trace state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/traceFlow?traceId={traceId}&timestamp={timestamp}&state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTraceHistory(self):
        """
        getTraceHistory Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/nwpi/traceHistory"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSession(self, payload):
        """
        getSession Description
        
        Parameters:
        payload:    Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def disableSpeedTestSession(self, sessionId):
        """
        disableSpeedTestSession Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/disable/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInterfaceBandwidth(self, circuit, deviceUUID):
        """
        getInterfaceBandwidth Description
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/interface/bandwidth?circuit={circuit}&deviceUUID={deviceUUID}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def startSpeedTest(self, sessionId):
        """
        startSpeedTest Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/start/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSpeedTestStatus(self, sessionId):
        """
        getSpeedTestStatus Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/status/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def stopSpeedTest(self, sessionId):
        """
        stopSpeedTest Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/stop/{sessionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def saveSpeedTestResults(self, payload, deviceUUID, sessionId):
        """
        saveSpeedTestResults Description
        
        Parameters:
        payload:    Request Payload
		Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/{deviceUUID}/{sessionId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getSpeedTest(self, sessionId, logId):
        """
        getSpeedTest Description
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/speed/{sessionId}?logId={logId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processDeviceStatus(self, payload, deviceUUID):
        """
        Get device status stream
        
        Parameters:
        payload:    Request Payload
		deviceUUID	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/stream/device/status/{deviceUUID}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Pattern(object):
    """
    Monitoring - Umbrella Patterns API
    
    Implements GET POST DEL PUT methods for UmbrellaPatterns endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, statsquerystring):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, statsquerystring):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getPostAggregationAppDataByQuery(self, statsquerystring):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, statsquerystring, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/fwall/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Chain(object):
    """
    Colocation - Service Chain API
    
    Implements GET POST DEL PUT methods for ServiceChain endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def attach(self, request):
        """
        Attach service chain to cluster
        
        Parameters:
        request:	Attach service chain request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicechain/attach"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def autoAttach(self, request):
        """
        Attach service chain to cluster
        
        Parameters:
        request:	Attach service chain request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicechain/autoattach"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def detach(self, request):
        """
        Detach service chain
        
        Parameters:
        request:	Detach service chain request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicechain/detach"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, request)
        return response


    def getEdgeDevices(self):
        """
        Get edge devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicechain/edge/devices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getpnfDevices(self, pnfDeviceType):
        """
        Get PNF edge devices
        
        Parameters:
        pnfDeviceType	 (string):	PNF device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicechain/edge/pnfdevices?pnfDeviceType={pnfDeviceType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Policy(object):
    """
    Real-Time Monitoring - Policy API
    
    Implements GET POST DEL PUT methods for Policy endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getAclAssociations(self, deviceId):
        """
        Get access list associations from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/accesslistassociations?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclCounters(self, deviceId):
        """
        Get access list counter from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/accesslistcounters?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclNames(self, deviceId):
        """
        Get access list names from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/accesslistnames?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclPolicers(self, deviceId):
        """
        Get access list policers from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/accesslistpolicers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAppRouteFilter(self, deviceId):
        """
        Get approute policy filter from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/approutepolicyfilter?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDataPolicyFilter(self, deviceId):
        """
        Get data policy filters from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/datapolicyfilter?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFilterMemUsage(self, deviceId):
        """
        Get data policy filter memory usage from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/filtermemoryusage?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclAssocV6(self, deviceId):
        """
        Get access list associations from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/ipv6/accesslistassociations?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclCountersV6(self, deviceId):
        """
        Get access list counters from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/ipv6/accesslistcounters?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclNamesV6(self, deviceId):
        """
        Get access list names from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/ipv6/accesslistnames?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAclPolicersV6(self, deviceId):
        """
        Get access list policers from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/ipv6/accesslistpolicers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQosMapInfo(self, deviceId):
        """
        Get QoS map information from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/qosmapinfo?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQosSchedulerInfo(self, deviceId):
        """
        Get QoS scheduler information from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/qosschedulerinfo?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRewriteAssocInfo(self, deviceId):
        """
        Get rewrite associations information from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/rewriteassociations?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSdwanPolicyFromVsmart(self, deviceId):
        """
        show Sdwan Policy From Vsmart
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/vsmart?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZoneDropStats(self, deviceId):
        """
        Get zone drop statistics from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/zbfwdropstatistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZbfwStats(self, deviceId):
        """
        Get zone based firewall statistics from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/zbfwstatistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZonePairSessions(self, deviceId):
        """
        Get zone pair sessions from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/zonepairsessions?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZonePairs(self, deviceId):
        """
        Get zone pair statistics from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/zonepairstatistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZonePolicyFilters(self, deviceId):
        """
        Get zone policy filter from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/policy/zonepolicyfilter?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Group(object):
    """
    Colocation - Service Group API
    
    Implements GET POST DEL PUT methods for ServiceGroup endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getServiceChain(self, serviceGroupName):
        """
        Get service chain by name
        
        Parameters:
        serviceGroupName	 (string):	Service group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup?serviceGroupName={serviceGroupName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def update(self, servicegroup):
        """
        Update service group
        
        Parameters:
        servicegroup:	Service group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, servicegroup)
        return response


    def create(self, servicegroup):
        """
        Add new service group
        
        Parameters:
        servicegroup:	Service group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, servicegroup)
        return response


    def getGroupInCluster(self, ClusterId, UserGroupName):
        """
        Get service chains in cluster
        
        Parameters:
        ClusterId	 (string):	Cluster Id
		UserGroupName	 (string):	UserGroup Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup/attached?ClusterId={ClusterId}&UserGroupName={UserGroupName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDefaultChain(self):
        """
        Get default service chains
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup/servicechain/default"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAvailableChains(self):
        """
        Get all service chains
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup/servicechains"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def delete(self, name):
        """
        Delete service group
        
        Parameters:
        name	 (string):	Service group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/servicegroup/{name}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class VedgeAssembly(object):
    """
    Configuration - Policy vEdge Assembler API
    
    Implements GET POST DEL PUT methods for Policy vEdge Assembler endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def preview(self, policyassembly):
        """
        Get policy assembly preview
        
        Parameters:
        policyassembly:	Policy assembly
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/assembly/vedge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policyassembly)
        return response


    def previewById(self, id):
        """
        Get policy assembly preview
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/assembly/vedge/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Alarm(object):
    """
    Monitoring - Alarms Details API
    
    Implements GET POST DEL PUT methods for AlarmsDetails endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getAlarms(self, query):
        """
        Get alarms for last 30min if vManage query is not specified
        
        Parameters:
        query	 (string):	Alarm query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRawData(self, alarmquerystring):
        """
        Gets lists of alarms along with the raw alarm data of each.
        
        Parameters:
        alarmquerystring:	Alarm query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms"
        response = self.client.apiCall(HttpMethods.POST, endpoint, alarmquerystring)
        return response


    def getAggregationData(self, query):
        """
        Gets aggregated list of alarms along with the raw alarm data of each aggregation
        
        Parameters:
        query	 (string):	Alarm query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationData(self, inputquery):
        """
        Gets aggregated list of alarms along with the raw alarm data of each aggregation
        
        Parameters:
        inputquery:	Input query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, inputquery)
        return response


    def clearStale(self, alarm_uuid):
        """
        Clears specific stale alarm
        
        Parameters:
        alarm_uuid:	alarm_uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/clear"
        response = self.client.apiCall(HttpMethods.POST, endpoint, alarm_uuid)
        return response


    def getNonViewedActiveCount(self):
        """
        Get count of the alarms which are active and acknowledged by the user
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/count"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listDisabled(self):
        """
        List all disabled alarms
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/disabled"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def disableEnable(self, alarmconfig, eventName, disable, time):
        """
        Enable/Disable a specific alarm
        
        Parameters:
        alarmconfig:	alarm config
		eventName	 (string):	Event name
		disable	 (boolean):	Disable
		time	 (integer):	time in hours [1, 72], -1 means infinite
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/disabled?eventName={eventName}&disable={disable}&time={time}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, alarmconfig)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def dumpCorrelationEngineData(self):
        """
        dump correlation engine server data
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/dump"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def markAllAsViewed(self, bodyParameter, type):
        """
        Mark all larms as acknowledged by the user
        
        Parameters:
        bodyParameter:	Description
		type	 (string):	Query filter, possible value are "active" "cleared"
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/markallasviewed?type={type}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def markAsViewed(self, listofalarms):
        """
        Mark alarms as acknowledged by the user
        
        Parameters:
        listofalarms:	List of alarms
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/markviewed"
        response = self.client.apiCall(HttpMethods.POST, endpoint, listofalarms)
        return response


    def getMasterManagerState(self):
        """
        Get master manager state
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/master"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNonViewed(self):
        """
        Get alarms which are active and acknowledged by the user
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/notviewed"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkAlarmRawData(self, query, scrollId, count):
        """
        Get paginated alarm raw data
        
        Parameters:
        query	 (string):	Alarm query string
		scrollId	 (string):	Query offset
		count	 (integer):	Query size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkAlarmRawData(self, alarmquerystring, scrollId, count):
        """
        Get paginated alarm raw data
        
        Parameters:
        alarmquerystring:	Alarm query string
		scrollId	 (string):	Query offset
		count	 (integer):	Query size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, alarmquerystring)
        return response


    def setPeriodicPurgeTimer(self, interval, activeTime):
        """
        Set alarm purge timer
        
        Parameters:
        interval	 (string):	Purge interval
		activeTime	 (string):	Purge activeTime
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/purgefrequency?interval={interval}&activeTime={activeTime}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQueryConfig(self):
        """
        Get query configuration
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/query/input"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def correlAntiEntropy(self):
        """
        Reset correlation engine data
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/reset"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def restartCorrelationEngine(self):
        """
        Restart correlation engine
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/restart"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTypesAsKeyValue(self):
        """
        Gets alarm type as key value pair
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/rulenamedisplay/keyvalue"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getBySeverity(self, level, deviceId, query):
        """
        Get alarm by severity
        
        Parameters:
        level	 (array):	Alarm severity
		deviceId	 (array):	Device Id
		query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/severity?severity-level={level}&deviceId={deviceId}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSeverityCustomHistogram(self, query):
        """
        Get alarm severity histogram
        
        Parameters:
        query	 (string):	Alarm histogram query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/severity/summary?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSeverityMappings(self):
        """
        Gets alarm severity mappings
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/severitymappings"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def startTracking(self, testName):
        """
        Start tracking events
        
        Parameters:
        testName	 (string):	test name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/starttracking/{testName}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getStats(self):
        """
        Get alarm statistics
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/stats"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def stopTracking(self, testName):
        """
        Stop tracking events
        
        Parameters:
        testName	 (string):	test name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/stoptracking/{testName}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getDeviceTopic(self, ip):
        """
        Get device topic state
        
        Parameters:
        ip	 (string):	Query topic
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/topic?ip={ip}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDetails(self, alarm_uuid):
        """
        Get alarm detail
        
        Parameters:
        alarm_uuid	 (string):	Alarm Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/alarms/uuid/{alarm_uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateNotificationRule(self, notificationrule, ruleId):
        """
        Update notification rule
        
        Parameters:
        notificationrule:	Notification rule
		ruleId	 (string):	Rule Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/notifications/rule?ruleId={ruleId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, notificationrule)
        return response


    def createNotificationRule(self, notificationrule):
        """
        Add notification rule
        
        Parameters:
        notificationrule:	Notification rule
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/notifications/rule"
        response = self.client.apiCall(HttpMethods.POST, endpoint, notificationrule)
        return response


    def getNotificationRule(self, ruleId):
        """
        Get all rules or specific notification rule by its Id
        
        Parameters:
        ruleId	 (string):	Rule Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/notifications/rules?ruleId={ruleId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteNotificationRule(self, ruleId):
        """
        Delete notification rule
        
        Parameters:
        ruleId	 (string):	Rule Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/notifications/rules?ruleId={ruleId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Registration(object):
    """
    Partner - Registration API
    
    Implements GET POST DEL PUT methods for Registration endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getPartners(self):
        """
        Get all NMS partners
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVPNList(self):
        """
        Get all VPNs
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/vpn"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPartnersByType(self, partnerType):
        """
        Get NMS partners by partner type
        
        Parameters:
        partnerType	 (string):	Partner type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def registerPartner(self, partner, partnerType):
        """
        Register NMS partner
        
        Parameters:
        partner:	Partner
		partnerType	 (string):	Partner type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, partner)
        return response


    def getPartnerDevices(self, partnerType, nmsId):
        """
        List mapped devices for the partner
        
        Parameters:
        partnerType     (string):   Partner type
		nmsId	        (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/map/{nmsId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def mapDevices(self, listofdevices, partnerType, nmsId):
        """
        Map devices for the partner
        
        Parameters:
        listofdevices:	            List of devices
		partnerType	    (string):	Partner type
		nmsId	        (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/map/{nmsId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, listofdevices)
        return response


    def unmapDevices(self, partnerType, nmsId):
        """
        Unmap all devices for the partner
        
        Parameters:
        partnerType     (string):   Partner type
		nmsId	        (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/map/{nmsId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def deleteDeviceMapping(self, listofdevices, partnerType, nmsId):
        """
        Unmap a set of devices for the partner
        
        Parameters:
        listofdevices:	List of devices
		partnerType	 (string):	Partner type
		nmsId	 (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/unmap/{nmsId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, listofdevices)
        return response


    def getPartner(self, partnerType, nmsId):
        """
        Get NMS partners by partner type and Id
        
        Parameters:
        partnerType	 (string):	Partner type
		nmsId	 (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/{nmsId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updatePartner(self, partner, partnerType, nmsId):
        """
        Update NMS partner details
        
        Parameters:
        partner:	                Partner
		partnerType	    (string):	Partner type
		nmsId	        (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/{nmsId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, partner)
        return response


    def deletePartner(self, partnerType, nmsId):
        """
        Delete NMS partner
        
        Parameters:
        partnerType	    (string):	Partner type
		nmsId	        (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/{partnerType}/{nmsId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getDataChangeInfo(self, partnerId, event_id, eventNames, wait_time):
        """
        Retrieve registration change information
        
        Parameters:
        partnerId	 (string):	Partner Id
		event_id	 (string):	Continuation token of ongoing event-polling session
		eventNames	 (array):	Names of type of events to filter on
		wait_time	 (integer):	Maximum polling wait time in seconds
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/serverlongpoll/event/poll/{partnerId}?event_id={event_id}&eventNames={eventNames}&wait_time={wait_time}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class AAA(object):
    """
    Real-Time Monitoring - AAA API
    
    Implements GET POST DEL PUT methods for AAA endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getServers(self, deviceId):
        """
        Get AAA servers from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/aaa/servers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUsers(self, deviceId):
        """
        Get AAA users from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/aaa/users?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getACLMatchCounterUsers(self, deviceId):
        """
        Get ACL match counters from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/acl/matchcounter?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLoggingFromDevice(self, deviceId):
        """
        Get logging from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/logging?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUnclaimedVedges(self, deviceId):
        """
        Get unclaimed vEdges from vbond
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/unclaimed/vedges?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUsersFromDevice(self, deviceId):
        """
        Get users from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/users?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllDeviceUsers(self, deviceId):
        """
        Get all users from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/users/list?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DpiOD(object):
    """
    Monitoring - DPI - On-demand troubleshooting API
    
    Implements GET POST DEL PUT methods for demandtroubleshooting endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getQueueEntries(self):
        """
        gets current on-demand queue entries
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/on-demand/queue"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createQueueEntry(self, queue):
        """
        Create on-demand troubleshooting queue entry
        
        Parameters:
        queue:	On-demand queue entry
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/on-demand/queue"
        response = self.client.apiCall(HttpMethods.POST, endpoint, queue)
        return response


    def getQueueProperties(self):
        """
        gets current size of on-demand queue
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/on-demand/queue/properties"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateQueueEntry(self, queue, entryId):
        """
        Updates on-demand troubleshooting queue entry
        
        Parameters:
        queue:	On-demand queue entry
		entryId	 (string):	Entry Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/on-demand/queue/{entryId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, queue)
        return response


    def deleteQueueEntry(self, entryId):
        """
        removes on-demand queue entry
        
        Parameters:
        entryId	 (string):	Entry Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/on-demand/queue/{entryId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Config(object):
    """
    Configuration - Template Configuration API
    
    Implements GET POST DEL PUT methods for TemplateConfiguration endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def uploadConfig(self, templateconfig, deviceId):
        """
        Upload device config
        
        Parameters:
        templateconfig:	Template config
		deviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/attach/{deviceId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, templateconfig)
        return response


    def getAttached(self, deviceId, type):
        """
        Get local template attached config for given device
        
        Parameters:
        deviceId	 (string):	Device Model ID
		type	 (string):	Config type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/attached/{deviceId}?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCLIModeDevices(self, type):
        """
        Generates a JSON object that contains a list of valid devices in CLI mode
        
        Parameters:
        type	 (string):	Device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/device/mode/cli?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateToCLI(self, devicelist):
        """
        Given a JSON list of devices not managed by any third member partners, push to devices from a CLI template
        
        Parameters:
        devicelist:	Device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/device/mode/cli"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def getvManageModeDevices(self, type):
        """
        Get list of devices that are allowable for vmanage modes
        
        Parameters:
        type	 (string):	Device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/device/mode/vmanage?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceDiff(self, deviceId):
        """
        Generates a JSON object that contains the diff for a given device
        
        Parameters:
        deviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/diff/{deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCompatibleDevices(self, oldDeviceId):
        """
        Get compatible devices of model, chassis number, certificate serial number with the old device
        
        Parameters:
        oldDeviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/rmalist/{oldDeviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def rmaUpdate(self, templateconfig):
        """
        Update new device
        
        Parameters:
        templateconfig:	Template config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/rmaupdate"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, templateconfig)
        return response


    def getRunningConfig(self, deviceId):
        """
        Get device running config
        
        Parameters:
        deviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/running/{deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVpnForDevice(self, deviceId):
        """
        Get list of configured VPN (excluding reserved VPN) for a device
        
        Parameters:
        deviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/config/vpn/{deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Device(object):
    """
    Monitoring - Device Details API
    
    Implements GET POST DEL PUT methods for DeviceDetails endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStateData(self, state_data_type, startId, count):
        """
        Get device state data
        
        Parameters:
        state_data_type	 (string):	State data type
		startId	 (string):	Start Id
		count	 (string):	Count
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/state/{state_data_type}?startId={startId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStateDataFields(self, state_data_type):
        """
        Get device state data fileds
        
        Parameters:
        state_data_type	 (string):	State data type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/state/{state_data_type}/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStateDataWithQuery(self, state_data_type):
        """
        Get device state data fileds
        
        Parameters:
        state_data_type	 (string):	State data type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/state/{state_data_type}/query"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listAllDevices(self):
        """
        List all devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setBlockSync(self, blockSync):
        """
        Set collection manager block set flag
        
        Parameters:
        blockSync	 (string):	Block sync flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/blockSync?blockSync={blockSync}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getRunning(self, deviceId):
        """
        Get device running configuration
        
        Parameters:
        deviceId	 (array):	Device Id list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/config?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRunningHtml(self, deviceId):
        """
        Get device running configuration in HTML format
        
        Parameters:
        deviceId	 (array):	Device Id list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/config/html?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceCounters(self):
        """
        Get device counters
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/counters"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceOnlyStatus(self):
        """
        Get devices status per type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/devicestatus"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def enableSDAVCOnDevice(self, deviceIP, enable):
        """
        Enable/Disable SDAVC on device
        
        Parameters:
        deviceIP	 (string):	Device IP
		enable	 (boolean):	Enable/Disable flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/enableSDAVC/{deviceIP}/{enable}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getHealthDetails(self, deviceId, state):
        """
        Get hardware health details for device
        
        Parameters:
        deviceId	 (string):	Device Id
		state	 (string):	Device state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardwarehealth/detail?deviceId={deviceId}&state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getHealthSummary(self, isCached, vpnId):
        """
        Get hardware health summary for device
        
        Parameters:
        isCached	 (boolean):	Status cached
		vpnId	 (array):	VPN Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardwarehealth/summary?isCached={isCached}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getListAsKeyValue(self):
        """
        Get vEdge inventory as key value (key as systemIp value as hostName)
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/keyvalue"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listAllModels(self, list):
        """
        Get all device models supported by the vManage
        
        Parameters:
        list	 (string):	List type of device
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/models?list={list}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceModels(self, uuid):
        """
        Get device model for the device
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/models/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listAllMonitorDetails(self):
        """
        Get all monitoring details of the devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/monitor"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncQueues(self):
        """
        Get synchronized queue information, returns information about syncing, queued and stuck devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/queues"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listReachable(self):
        """
        Get list of reachable devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/reachable"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsQueues(self):
        """
        Get stats queue information
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/stats"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllStatus(self):
        """
        Get devices status for vSmart,vBond,vEdge, and cEdge
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listSyncing(self, groupId):
        """
        Get list of currently syncing devices
        
        Parameters:
        groupId	 (string):	Group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sync_status?groupId={groupId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def syncAllMemDB(self):
        """
        Synchronize memory database for all devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/syncall/memorydb"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getDeviceTlocStatus(self, deviceId, color):
        """
        Get TLOC status list
        
        Parameters:
        deviceId	 (string):	Device Id
		color	 (string):	Status color
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tloc?deviceId={deviceId}&color={color}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTlocUtil(self):
        """
        Get TLOC list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tlocutil"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTlocUtilDetails(self, util):
        """
        Get detailed TLOC list
        
        Parameters:
        util	 (string):	Tloc util
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tlocutil/detail?util={util}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listUnreachable(self, personality):
        """
        Get list of unreachable devices
        
        Parameters:
        personality	 (string):	Device personality
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/unreachable?personality={personality}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def removeUnreachable(self, deviceIP):
        """
        Delete unreachable device
        
        Parameters:
        deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/unreachable/{deviceIP}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getVedgeInventory(self, status):
        """
        Get detailed vEdge inventory
        
        Parameters:
        status	 (string):	Device status
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vedgeinventory/detail?status={status}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVedgeInventorySummary(self):
        """
        Get vEdge inventory
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vedgeinventory/summary"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVManageSystemIP(self):
        """
        Get vManage system IP
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vmanage"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Bridge(object):
    """
    Real-Time Monitoring - Bridge API
    
    Implements GET POST DEL PUT methods for Bridge endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getInterfaces(self, deviceId):
        """
        Get device bridge interface list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bridge/interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInterfaceMac(self, bridgeId, ifName, macAddr, deviceId):
        """
        Get device bridge interface MAC (Real Time)
        
        Parameters:
        bridgeId	 (string):	Bridge ID
		ifName	 (string):	Interface name
		macAddr	 (string):	MAC address
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bridge/mac?bridgeId={bridgeId}&ifName={ifName}&macAddr={macAddr}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getBridgeInterfaceTable(self, deviceId):
        """
        Get device bridge interface table (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bridge/table?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class UTD(object):
    """
    Real-Time Monitoring - UTD API
    
    Implements GET POST DEL PUT methods for UTD endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getUTDDataplaneConfig(self, deviceId):
        """
        Get data plane config from Device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/dataplane-config?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDDataplaneGlobal(self, deviceId):
        """
        Get data plane global from Device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/dataplane-global?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDDataplaneStats(self, deviceId):
        """
        Get data plane stats from Device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/dataplane-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDDataplaneStatsSummary(self, deviceId):
        """
        Get data plane stats summary
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/dataplane-stats-summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDEngineInstanceStatus(self, deviceId):
        """
        Get UTD engine instance status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/engine-instance-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDEngineStatus(self, deviceId):
        """
        Get UTD engine status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/engine-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDFileAnalysisStatus(self, deviceId):
        """
        Get UTD file analysis status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/file-analysis-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDFileReputationStatus(self, deviceId):
        """
        Get UTD file reputation status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/file-reputation-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDIpsUpdateStatus(self, deviceId):
        """
        Get UTD IPS update status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/ips-update-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSignatureVersionInfo(self, deviceId):
        """
        Get UTD Signature version information from Device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/signature/version/details?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDUrlfConnectionStatus(self, deviceId):
        """
        Get UTD URLF Connection status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/urlf-con-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDUrlfUpdateStatus(self, deviceId):
        """
        Get UTD URLF update status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/urlf-update-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUTDVersionStatus(self, deviceId):
        """
        Get UTD version status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/utd/version-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Ucse(object):
    """
    Real-Time Monitoring - Ucse API
    
    Implements GET POST DEL PUT methods for Ucse endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def createUcseStats(self, remote_tloc_address, remote_tloc_color, local_tloc_color, deviceId):
        """
        Get  UCSE stats entry from device
        
        Parameters:
        remote_tloc_address	 (string):	Remote TLOC address
		remote_tloc_color	 (string):	Remote tloc color
		local_tloc_color	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ucse/stats?remote-tloc-address={remote_tloc_address}&remote-tloc-color={remote_tloc_color}&local-tloc-color={local_tloc_color}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DeviceGroup(object):
    """
    Troubleshooting Tools - Device Group API
    
    Implements GET POST DEL PUT methods for Device Group endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def listDeviceGroupList(self):
        """
        Retrieve device group list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/group"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listDeviceGroups(self):
        """
        Retrieve device groups
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/group/device"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listGroupDevices(self, groupId, ssh, vpnId):
        """
        Retrieve devices in group
        
        Parameters:
        groupId	 (string):	Group Id
		ssh	 (boolean):	SSH
		vpnId	 (array):	VPN Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/group/devices?groupId={groupId}&ssh={ssh}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listGroupDevicesForMap(self, groupId, vpnId):
        """
        Retrieve group devices for map
        
        Parameters:
        groupId	 (string):	Group Id
		vpnId	 (array):	VPN Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/group/map/devices?groupId={groupId}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listGroupLinksForMap(self, groupId):
        """
        Retrieve devices in group for map
        
        Parameters:
        groupId	 (string):	Group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/group/map/devices/links?groupId={groupId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class VDSLService(object):
    """
    Real-Time Monitoring - VDSL Service API
    
    Implements GET POST DEL PUT methods for VDSLService endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCoLineSpecificStats(self, deviceId):
        """
        Get VDSL service line bonding stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/coLineSpecificStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCoStats(self, deviceId):
        """
        Get CO stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/coStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCpeLineSpecificStats(self, deviceId):
        """
        Get VDSL service CPE line specific stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/cpeLineSpecificStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCpeStats(self, deviceId):
        """
        Get CPE stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/cpeStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLineBondingStats(self, deviceId):
        """
        Get VDSL service line bonding stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/lineBondingStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLineSpecificStats(self, deviceId):
        """
        Get VDSL service line specific stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/lineSpecificStats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVdslInfo(self, deviceId):
        """
        Get VDSL info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/vdslService/vdslInfo?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Connectivity(object):
    """
    Troubleshooting Tools - Device Connectivity API
    
    Implements GET POST DEL PUT methods for Device Connectivity endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def invalidateDevice(self, devInfo):
        """
        invalidate the device
        
        Parameters:
        devInfo:	vEdge device info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/device/invalidate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devInfo)
        return response


    def stageDevice(self, devInfo):
        """
        Stop data traffic to device
        
        Parameters:
        devInfo:	vEdge device info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/device/stage"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devInfo)
        return response


    def createAdminTech(self, request):
        """
        Generate admin tech logs
        
        Parameters:
        request:	Admin tech generation request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintech"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def copyAdminTechOnDevice(self, request):
        """
        copy admin tech logs
        
        Parameters:
        request:	Admin tech copy request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintech/copy"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def deleteAdminTechOnDevice(self, request):
        """
        delete admin tech logs
        
        Parameters:
        request:	Admin tech copy request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintech/delete"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, request)
        return response


    def downloadAdminTechFile(self, filename):
        """
        Download admin tech logs
        
        Parameters:
        filename	 (string):	Admin tech file
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintech/download/{filename}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteAdminTechFile(self, requestID):
        """
        Delete admin tech logs
        
        Parameters:
        requestID	 (string):	Request Id of admin tech generation request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintech/{requestID}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def listAdminTechsOnDevice(self, request):
        """
        List admin tech logs
        
        Parameters:
        request:	Admin tech listing request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintechlist"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def listAdminTechs(self):
        """
        Get device admin-tech information
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintechs"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInProgressCount(self):
        """
        Get device admin-tech InProgressCount
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/admintechs/inprogress"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def factoryReset(self, payload):
        """
        Device factory reset
        
        Parameters:
        payload:	Device factory reset
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/factoryreset"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def npingDevice(self, npingparameter, deviceIP):
        """
        NPing device
        
        Parameters:
        npingparameter:	NPing parameter
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/nping/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, npingparameter)
        return response


    def pingDevice(self, pingparameter, deviceIP):
        """
        Ping device
        
        Parameters:
        pingparameter:	Ping parameter
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/ping/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, pingparameter)
        return response


    def processPortHopColor(self, deviceporthopcolor, deviceIP):
        """
        Request port hop color
        
        Parameters:
        deviceporthopcolor:	Device port hop color
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/porthopcolor/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceporthopcolor)
        return response


    def processInterfaceReset(self, deviceinterface, deviceIP):
        """
        Reset device interface
        
        Parameters:
        deviceinterface:	Device interface
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/reset/interface/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceinterface)
        return response


    def processResetUser(self, deviceuserreset, deviceIP):
        """
        Request reset user
        
        Parameters:
        deviceuserreset:	Device user reset
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/resetuser/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceuserreset)
        return response


    def servicePath(self, servicepathparameter, deviceIP):
        """
        Service path
        
        Parameters:
        servicepathparameter:	Service path parameter
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/servicepath/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, servicepathparameter)
        return response


    def tracerouteDevice(self, tracerouteparameter, deviceIP):
        """
        Traceroute
        
        Parameters:
        tracerouteparameter:	Traceroute parameter
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/traceroute/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tracerouteparameter)
        return response


    def tunnelPath(self, tunnelpathparameter, deviceIP):
        """
        TunnelPath
        
        Parameters:
        tunnelpathparameter:	TunnelPath parameter
		deviceIP	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tools/tunnelpath/{deviceIP}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tunnelpathparameter)
        return response


    def getControlConnections(self, uuid):
        """
        Troubleshoot control connections
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/troubleshooting/control/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceConfiguration(self, uuid):
        """
        Debug device bring up
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/troubleshooting/devicebringup?uuid={uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Manage(object):
    """
    Tenant Management API
    
    Implements GET POST DEL PUT methods for Tenant Management endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAllTenants(self, deviceId):
        """
        Lists all the tenants on the vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        deviceId	 (string):	List all tenants associated with a vSmart
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createTenant(self, tenantModel):
        """
        Create a new tenant in Multi-Tenant vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tenantModel)
        return response


    def createTenantAsync(self, tenantModel):
        """
        Create a new tenant in Multi-Tenant vManage asynchronously
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/async"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tenantModel)
        return response


    def createTenantAsyncBulk(self, tenantModel):
        """
        Create multiple tenants on vManage asynchronously
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/bulk/async"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tenantModel)
        return response


    def deleteTenantAsyncBulk(self, tenantModel):
        """
        Delete multiple tenants on vManage asynchronously
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/bulk/async"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, tenantModel)
        return response


    def getTenantvSmartMapping(self):
        """
        Retrieve mapping of tenants to vSmarts
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/vsmart"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def tenantvSmartMtMigrate(self):
        """
        Migrate tenants from single tenant vSmarts to multi-tenant capable vSmarts
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/vsmart-mt/migrate"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getTenantHostingCapacityOnvSmarts(self):
        """
        Lists all the vsmarts on the vManage and its tenant hosting capacity
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/vsmart/capacity"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTenant(self, tenantId):
        """
        Get a tenant by Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantId	 (string):	Tenant Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/{tenantId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateTenant(self, tenantModel, tenantId):
        """
        Update a tenant in Multi-Tenant vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
		tenantId	 (string):	Tenant Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/{tenantId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, tenantModel)
        return response


    def deleteTenant(self, tenantModel, tenantId):
        """
        Delete a tenant by Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantModel:	Tenant model
		tenantId	 (string):	Tenant Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/{tenantId}/delete"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tenantModel)
        return response


    def switchTenant(self, tenantId):
        """
        Switch to a specific tenant
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantId	 (string):	Tenant Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/{tenantId}/switch"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def vSessionId(self, tenantId):
        """
        Get VSessionId for a specific tenant
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantId	 (string):	Tenant Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenant/{tenantId}/vsessionid"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getAllTenantStatuses(self):
        """
        List all tenant status
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantstatus"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def forceStatusCollection(self):
        """
        Force tenant status collection
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantstatus/force"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class AppHosting(object):
    """
    Real-Time Monitoring - App Hosting API
    
    Implements GET POST DEL PUT methods for AppHosting endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAttached(self, deviceId):
        """
        Get App hosting attached device from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/attached-devices?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDetails(self, deviceId):
        """
        Get App hosting details from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/details?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getGuestRoutes(self, deviceId):
        """
        Get App hosting guest routes from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/guest-routes?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNetworkDevices(self, deviceId):
        """
        Get App hosting network interface from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/network-interfaces?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNetworkUtils(self, deviceId):
        """
        Get App hosting network utilization from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/network-utilization?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProcesses(self, deviceId):
        """
        Get App hosting processes from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/processes?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStorageUtils(self, deviceId):
        """
        Get App hosting storage utilization from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/storage-utilization?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUtilization(self, deviceId):
        """
        Get App hosting utilization from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-hosting/utilization?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class NetworkDesign(object):
    """
    Configuration - Network Design API
    
    Implements GET POST DEL PUT methods for Network Design endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getNetworkDesign(self):
        """
        Get existing network design
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editNetworkDesign(self, payload, id):
        """
        Edit network segment
        
        Parameters:
        payload:	Network design payload
		id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign?id={id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, payload)
        return response


    def createNetworkDesign(self, payload):
        """
        Create network design
        
        Parameters:
        payload:	Network design payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def pushNetworkDesign(self, devicetemplate):
        """
        Attach network design
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/attachment"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def getGlobalParams(self):
        """
        Get global parameter templates
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/global/parameters"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def acquireEditLock(self):
        """
        Acquire edit lock
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/lock/edit"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def runMyTest(self, name):
        """
        Get all device templates for this feature template
        
        Parameters:
        name	 (string):	Test bane
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/mytest/{name}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def pushDeviceProfileTemplate(self, devicetemplate, profileId):
        """
        Attach to device profile
        
        Parameters:
        devicetemplate:	Device template
		profileId	 (string):	Device profile Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/attachment/{profileId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def acquireAttachLock(self, profileId):
        """
        Get the service profile config for a given device profile id
        
        Parameters:
        profileId	 (string):	Device profile Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/lock/{profileId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getConfigStatus(self):
        """
        Get device profile configuration status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConfigStatusById(self, profileId):
        """
        Get device profile configuration status by profile Id
        
        Parameters:
        profileId	 (string):	Device profile Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/status/{profileId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTaskCount(self):
        """
        Get device profile configuration task count
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/task/count"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTaskStatus(self):
        """
        Get device profile configuration task status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/task/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTaskStatusById(self, profileId):
        """
        Get device profile configuration status by profile Id
        
        Parameters:
        profileId	 (string):	Device profile Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/task/status/{profileId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServiceProfileConfig(self, profileId, deviceModel):
        """
        Get the service profile config for a given device profile id
        
        Parameters:
        profileId	 (string):	Device profile Id
		deviceModel	 (string):	Device model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/serviceProfileConfig/{profileId}?deviceModel={deviceModel}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class BGP(object):
    """
    Real-Time Monitoring - BGP API
    
    Implements GET POST DEL PUT methods for BGP endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getNeighbors(self, vpnId, peerAddr, asNo, deviceId):
        """
        Get BGP neighbors list (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		peerAddr	 (string):	Peer address
		asNo	 (string):	AS number
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bgp/neighbors?vpnId={vpnId}&peerAddr={peerAddr}&as={asNo}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createBGPRoutesList(self, vpnId, prefix, nexthop, deviceId):
        """
        Get BGP routes list (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		prefix	 (string):	IP prefix
		nexthop	 (string):	Next hop
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bgp/routes?vpnId={vpnId}&prefix={prefix}&nexthop={nexthop}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createBGPSummary(self, deviceId):
        """
        Get BGP summary (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bgp/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DPI(object):
    """
    Real-Time Monitoring - DPI API
    
    Implements GET POST DEL PUT methods for DPI endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getDPIDeviceFieldJSON(self, isDeviceDashBoard):
        """
        Get DPI query field from device
        
        Parameters:
        isDeviceDashBoard	 (boolean):	Flag whether is device dashboard request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/application/fields?isDeviceDashBoard={isDeviceDashBoard}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDPICollectorList(self, vpnId, application, family, deviceId):
        """
        Get DPI applications from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		family	 (string):	Family
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/applications?vpn-id={vpnId}&application={application}&family={family}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCommonAppList(self):
        """
        Get DPI common application list from device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/common/applications"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPIFieldJSON(self):
        """
        Get DPI field from device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/device/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPIDeviceDetailsFieldJSON(self):
        """
        Get DPI detailed field from device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/devicedetails/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPIFlowsList(self, vpnId, ip, application, family, deviceId):
        """
        Get DPI flow list from device (Real Time)
        
        Parameters:
        vpnId	            (string):	VPN Id
		ip	                (string):	Source IP
		application	        (string):	Application
		family	            (string):	Family
		deviceId	        (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/flows?vpn-id={vpnId}&src-ip={ip}&application={application}&family={family}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQosmosAppList(self):
        """
        Get DPI QoSMos application list from device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/qosmos/applications"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPISummaryRealTime(self, deviceId):
        """
        Get DPI summary from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPIStatistics(self, application, family, deviceId):
        """
        Get supported applications from device (Real Time)
        
        Parameters:
        application	 (string):	Application
		family	 (string):	Family
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dpi/supported-applications?application={application}&family={family}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Container(object):
    """
    System - Container API
    
    Implements GET POST DEL PUT methods for Container endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def activateContainerOnRemoteHost(self, containerName, url, hostIp, checksum):
        """
        Activate container on remote host
        
        Parameters:
        containerName	 (string):	Container name
		url	 (string):	Container image URL
		hostIp	 (string):	Container host IP
		checksum	 (string):	Container image checksum
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/container-manager/activate/{containerName}?url={url}&hostIp={hostIp}&checksum={checksum}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def deActivateContainer(self, containerName, hostIp):
        """
        Deactivate container on remote host
        
        Parameters:
        containerName	 (string):	Container name
		hostIp	 (string):	Container host IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/container-manager/deactivate/{containerName}?hostIp={hostIp}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def doesValidImageExist(self, containerName):
        """
        Get container image checksum
        
        Parameters:
        containerName	 (string):	Container name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/container-manager/doesValidImageExist/{containerName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getContainerInspectData(self, containerName, hostIp):
        """
        Get container inspect data
        
        Parameters:
        containerName	 (string):	Container name
		hostIp	 (string):	Container host IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/container-manager/inspect/{containerName}?hostIp={hostIp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getContainerSettings(self, containerName, hostIp):
        """
        Get container settings
        
        Parameters:
        containerName	 (string):	Container name
		hostIp	 (string):	Container host IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/container-manager/settings/{containerName}?hostIp={hostIp}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getChecksum(self):
        """
        Get container image checksum
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/checksum"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCustomApp(self):
        """
        Displays the user-defined applications
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/customapps"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def activateContainer(self, containertaskconfig, taskId):
        """
        Activate container
        
        Parameters:
        containertaskconfig:	Container task config
		taskId	 (string):	Task Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/task/{taskId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, containertaskconfig)
        return response


    def testLoadBalancer(self):
        """
        Test SD_AVC load balancer
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/test"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


